@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,7 +21,7 @@
 #include "sieveserversettings.h"
 #include "sieveeditor_debug.h"
 
-#include <kwallet.h>
+#include <KWallet>
 
 #include <KConfig>
 
